@@ -14,7 +14,7 @@ mod drain_filter;
 pub use drain_filter::drain_filter;
 
 mod log_formatter;
-pub use log_formatter::LogFormatter;
+pub use log_formatter::{LogFormatter, WriteFormatter};
 
 #[cfg(feature = "async")]
 pub mod futures;
