@@ -6,5 +6,8 @@ pub use wait::{wait, wait_random};
 mod generic_codec;
 pub use generic_codec::GenericCodec;
 
+mod generic_lines_codec;
+pub use generic_lines_codec::GenericLinesCodec;
+
 #[cfg(feature = "test")]
 pub mod test;
